@@ -116,9 +116,13 @@ class Project:
     def timezone(self):
         if self._timezone:
             return self._timezone
-        for m in self.models():
-            if m.timezone:
-                return m.timezone
+        timezones = list(set(m.timezone for m in self.models() if m.timezone))
+        if len(timezones) == 1:
+            return timezones[0]
+        elif len(timezones) > 1:
+            raise QueryError(
+                "Multiple timezones found in models, please specify only one timezone across models"
+            )
         return None
 
     @property
@@ -409,16 +413,17 @@ class Project:
                 return all(decisions)
         return True
 
-    def _all_views(self, model):
+    def _all_views(self, model, show_hidden: bool = True):
         views = []
         for v in self._views:
             view = View({**v, "model": model}, project=self)
-            if self.can_access_view(view):
+            view_is_visible = show_hidden or view.hidden is False
+            if self.can_access_view(view) and view_is_visible:
                 views.append(view)
         return views
 
-    def views(self, model: Union[Model, None] = None) -> list:
-        return self._all_views(model)
+    def views(self, model: Union[Model, None] = None, show_hidden: bool = True) -> list:
+        return self._all_views(model, show_hidden)
 
     def get_view(self, view_name: str, model: Union[Model, None] = None) -> View:
         try:
