@@ -1,4 +1,4 @@
-from collections import defaultdict
+from collections import Counter, defaultdict
 from copy import deepcopy
 from typing import List, Union
 
@@ -42,7 +42,8 @@ class SQLQueryResolver(SingleSQLQueryResolver):
         always_where = self._apply_always_filter(metrics + dimensions)
         if always_where:
             self.where.extend(always_where)
-        self.having = having
+        self.where = self._clean_conditional_filter_syntax(self.where)
+        self.having = self._clean_conditional_filter_syntax(having)
         self.order_by = order_by
         self.kwargs = kwargs
         self.connection = self._get_connection(self.model.connection)
@@ -392,7 +393,17 @@ class SQLQueryResolver(SingleSQLQueryResolver):
         if self._is_literal(where):
             return where.replace(to_replace, field.id())
         else:
-            return [{**w, "field": field.id()} if w["field"] == to_replace else w for w in where]
+            result = []
+            for w in where:
+                if "field" in w and w["field"] == to_replace:
+                    result.append({**w, "field": field.id()})
+                elif "field" not in w and "conditions" in w:
+                    result.append(
+                        {**w, "conditions": self._replace_dict_or_literal(w["conditions"], to_replace, field)}
+                    )
+                else:
+                    result.append(w)
+            return result
 
     def _get_model_for_query(self, model_name: str = None, metrics: list = [], dimensions: list = []):
         models = self.project.models()
@@ -413,7 +424,7 @@ class SQLQueryResolver(SingleSQLQueryResolver):
             return self._derive_model(metrics, dimensions)
 
     def _derive_model(self, metrics: list, dimensions: list):
-        all_model_names = []
+        all_model_names, mapping_model_names = [], []
         models = self.project.models()
         for f in metrics + dimensions:
             try:
@@ -423,18 +434,21 @@ class SQLQueryResolver(SingleSQLQueryResolver):
                 for model in models:
                     try:
                         self.project.get_mapped_field(f, model=model)
-                        all_model_names.append(model.name)
-                        break
+                        mapping_model_names.append(model.name)
                     except Exception:
                         pass
 
         all_model_names = list(set(all_model_names))
-
-        if len(all_model_names) == 0:
+        if len(all_model_names) == 0 and len(mapping_model_names) > 0:
             # In a case that there are no models in the query, we'll just use the first model
             # in the project. This case should be limited to only mapping-only queries, so this is safe.
-            return self.project.models()[0]
-        elif len(all_model_names) == 1:
+            model_counts = Counter(mapping_model_names)
+            sorted_models = [m for m, _ in model_counts.most_common()]
+            return self.project.get_model(sorted_models[0])
+        elif len(all_model_names) == 1 and (
+            len(mapping_model_names) == 0
+            or (len(mapping_model_names) > 0 and all_model_names[0] in mapping_model_names)
+        ):
             return self.project.get_model(list(all_model_names)[0])
         else:
             raise QueryError(
@@ -485,6 +499,22 @@ class SQLQueryResolver(SingleSQLQueryResolver):
                 cleaned_filters.append(f)
         return cleaned_filters
 
+    def _clean_conditional_filter_syntax(self, filters: Union[str, None, List]):
+        if not filters or isinstance(filters, str):
+            return filters
+        if isinstance(filters, dict):
+            return [filters]
+
+        def process_filter(filter_obj):
+            if isinstance(filter_obj, dict):
+                if "conditional_filter_logic" in filter_obj:
+                    return filter_obj["conditional_filter_logic"]
+                elif "conditions" in filter_obj:
+                    filter_obj["conditions"] = [process_filter(cond) for cond in filter_obj["conditions"]]
+            return filter_obj
+
+        return [process_filter(filter_obj) for filter_obj in filters]
+
     def _get_connection_schema(self, connection):
         if connection is not None:
             return getattr(connection, "schema", None)
